==> blobAndConquer-0.1-1.tar.gz: BlobAndConquer/src/controlPanel.cpp <==
/*
Copyright (C) 2005 Parallel Realities

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.

See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

*/

#include "controlPanel.h"

void drawSlotItem(EntityDef *def, int x, int y, float scale)
{
	graphics->setMode(MODE_3D);
	
	if (def->model == NULL)
	{
		return;
	}
	
	static Vector near, far, ray;
	
	graphics->convertToWorldCoords(x, y, &near, &far, &ray);
	
	float adjust = (-2 - near.z) / ray.z;
	
	near.x += (ray.x * adjust);
	near.y += (ray.y * adjust);
	near.z += -2;
	
	scale /= graphics->screen->w;
	
	glEnable(GL_DEPTH_TEST);
	glDepthMask(GL_TRUE);
	
	glPushMatrix();
	{
		glEnable(GL_TEXTURE_2D);
		glDisable(GL_BLEND);
		
		glBindTexture(GL_TEXTURE_2D, def->texture->data);
		
		glTranslatef(near.x, near.y, near.z);
		glRotatef(graphics->getAnimTimer() * 0.5, 1.0, 1.0, 0.0);
		
		glScalef(scale, scale, scale);
		
		glCallList(def->model->data);
	}
	glPopMatrix();
}

void drawBlobHealthShieldInfo()
{
	static float healthPercent;
	static float healthBar, shieldBar, oxygenBar;
	static int fade;
	static int y;
	static String s;
	static GLColor c;
	static Texture *t;
	
	static GLColor darkRed = GLColor::red.darker();
	static GLColor darkYellow = GLColor::yellow.darker();
	static GLColor darkCyan = GLColor::cyan.darker();
	static GLColor darkGreen = GLColor::green.darker();
	
	y = 20;
	
	for (Unit *unit = (Unit*)entityManager->blobList.getFirstElement() ; unit != NULL ; unit = (Unit*)unit->next)
	{
		if ((unit->health <= -100) || (unit->definition->type == BLOB_MIA))
		{
			continue;
		}
		
		fade = 35;
		
		if (unit->maxShield > 0)
		{
			fade = 40;
		}
		
		if (unit->oxygen < MAX_OXYGEN)
		{
			fade = 45;
		}
		
		graphics->fade(0.5, 30, y - 5, 210, fade);
		
		s.setText("str_%s", unit->getName());
		
		if ((t = textureManager->getTexture(s.getText())) == NULL)
		{
			t = graphics->getGLString(unit->getName());
			textureManager->addTexture(s.getText(), t);
		}
		
		glColor3f(1.0, 1.0, 1.0);
		graphics->blit(t, 35, y, false);
		
		healthPercent = (unit->health / unit->maxHealth) * 100;
		
		healthBar = 200;
		shieldBar = 200;
		oxygenBar = 200;
		
		healthBar /= unit->maxHealth;
		shieldBar /= unit->maxShield;
		oxygenBar /= MAX_OXYGEN;
		
		healthBar *= unit->health;
		shieldBar *= unit->shield;
		oxygenBar *= unit->oxygen;
		
		y += 16;
		
		if (healthPercent >= 75)
		{
			c = darkGreen;
		}
		else if (healthPercent >= 25)
		{
			c = darkYellow;
		}
		else
		{
			c = darkRed;
		}
		
		graphics->drawRect(35, y, 200, 8, c, true);
		
		if ((unit == player) && (unit->health > 0) && (healthPercent < 25))
		{
			if ((((int)graphics->getAnimTimer()) % 100) < 50)
			{
				graphics->drawRect(35, y, (int)healthBar, 8, c, true);
			}
		}
		else if (unit->health > 0)
		{
			graphics->drawRect(35, y, (int)healthBar, 8, c, true);
		}
		
		y += 10;
		
		if (unit->maxShield > 0)
		{
			graphics->drawRect(35, y, 200, 4, darkCyan, true);
			
			if (unit->shield > 0)
			{
				graphics->drawRect(35, y, (int)shieldBar, 4, GLColor::cyan, true);
			}
		}
		
		y += 6;
		
		if (unit->oxygen < MAX_OXYGEN)
		{
			graphics->drawRect(35, y, 200, 4, darkYellow, true);
			
			if (unit->oxygen > 0)
			{
				graphics->drawRect(35, y, (int)oxygenBar, 4, GLColor::yellow, true);
			}
		}
		else if (unit->oxygen != MAX_OXYGEN_IND)
		{
			graphics->drawRect(35, y, 200, 4, GLColor::yellow, true);
		}
		
		if ((unit->definition->type == BLOB_TEEKA) && (game->teekaAvailableTimer > 0))
		{
			graphics->fade(0.75, 30, y - 37, 210, fade);
		}
		
		y += 20;
	}
}

void drawWeaponsAndItems()
{
	int x1 = 5;
	int x2 = (graphics->screen->w - 100) - 5;
	int y1 = graphics->screen->h - 100;
	
	graphics->fade(0.75, x1, y1, 100, 95);
	graphics->outlineRect(x1, y1, 100, 95, GLColor::grey);
	
	graphics->fade(0.75, x2, y1, 100, 95);
	graphics->outlineRect(x2, y1, 100, 95, GLColor::grey);
	
	drawSlotItem(game->selectedWeapon->definition, x1 + 40, graphics->screen->h - 40, 15);
	
	graphics->setMode(MODE_2D);
	
	String s;
	Texture *t;
	
	if (!(game->selectedWeapon->definition->flags & WF_UNLIMITED))
	{
		if ((t = textureManager->getTexture("str_current_ammo")) == NULL)
		{
			t = graphics->getGLString("%d", game->selectedWeapon->currentAmmo);
			textureManager->addTexture("str_current_ammo", t);
		}
		
		glColor3f(1.0, 1.0, 1.0);
		graphics->blit(t, 55, graphics->screen->h - 18, true);
	}
	
	for (int i = 0 ; i < 4 ; i++)
	{
		if (game->weapon[i] != NULL)
		{
			s.setText("str_weapon_%d", i);
			
			if ((t = textureManager->getTexture(s.getText())) == NULL)
			{
				if (game->weapon[i]->definition->flags & WF_UNLIMITED)
				{
					t = graphics->getGLString(game->weapon[i]->definition->getName());
				}
				else
				{
					t = graphics->getGLString("%s: %d", game->weapon[i]->definition->getName(), game->weapon[i]->currentAmmo);
				}
				
				textureManager->addTexture(s.getText(), t);
			}
			
			glColor3f(1.0, 1.0, 1.0);
			
			if (game->weapon[i]->currentAmmo == 0)
			{
				glColor3f(0.5, 0.5, 0.5);
			}
			
			if (game->weapon[i] == game->selectedWeapon)
			{
				glColor3f(0.0, 1.0, 0.0);
			}
		
			graphics->blit(t, 110, y1, false);
		}
		
		y1 += 25;
	}
	
	y1 = graphics->screen->h - 100;
	x2 -= 5;
	
	for (int i =  0 ; i < 5 ; i++)
	{
		if (game->item[i] != NULL)
		{
			if (game->item[i]->name != "")
			{
				graphics->drawString(x2 , y1, TXT_RIGHT, GLColor::white, true, "%s (%s)", game->item[i]->definition->getName(), game->item[i]->getName());
			}
			else
			{
				graphics->drawString(x2 , y1, TXT_RIGHT, GLColor::white, true, "%s", game->item[i]->definition->getName());
			}
		}
		
		y1 += 20;
	}
}

void drawMessages()
{
	Texture *t;
	String s;
	
	int y1 = graphics->screen->h - 100;
	
	for (int i = 0 ; i < 4 ; i++)
	{
		if (game->infoMessage[i].life > 0)
		{
			switch (game->infoMessage[i].type)
			{
				case INFO_PICKUP:
					glColor4fv(GLColor::cyan.color);
					break;
					
				case INFO_BAD:
					glColor4fv(GLColor::red.color);
					break;
					
				case INFO_GOOD:
					glColor4fv(GLColor::green.color);
					break;
					
				case INFO_HINT:
					glColor4fv(GLColor::yellow.color);
					break;
					
				case INFO_GENERAL:
					glColor4fv(GLColor::white.color);
					break;
			}
			
			s.setText("str_message_%d", i);
			
			if (game->infoMessage[i].redraw)
			{
				textureManager->removeTexture(s.getText());
				game->infoMessage[i].redraw = false;
			}
			
			if ((t = textureManager->getTexture(s.getText())) == NULL)
			{
				t = graphics->getGLString(game->infoMessage[i].message.getText());
				textureManager->addTexture(s.getText(), t);
			}
		
			graphics->blit(t, graphics->screen->w / 2, y1, true);
			
			y1 += 25;
			
			game->infoMessage[i].life -= engine->getTimeDifference(TD_LOGIC);
			
			if (game->infoMessage[i].life <= 0)
			{
				textureManager->removeTexture(s.getText());
			}
		}
	}
		
	if ((game->gameplayMessage.life > 0) && (engine->doGameLogic))
	{
		s.setText("str_message_gameplay");
			
		if ((t = textureManager->getTexture(s.getText())) == NULL)
		{
			t = graphics->getGLString(game->gameplayMessage.message.getText());
			textureManager->addTexture(s.getText(), t);
		}
		
		int x = (graphics->screen->w - t->iw) / 2;
		int y = graphics->screen->h - 135;
		int w = t->iw;
		int h = t->ih;
		
		graphics->fade(0.65, x - 10, y - 5, w + 15, h + 10);
		graphics->outlineRect(x - 10, y - 5, w + 15, h + 10, GLColor::lightGrey);
		glColor3f(1.0, 1.0, 1.0);
		glEnable(GL_BLEND);
		graphics->blit(t, x, y, false);
		
		game->gameplayMessage.life -= engine->getTimeDifference(TD_LOGIC);
			
		if (game->gameplayMessage.life <= 0)
		{
			textureManager->removeTexture(s.getText());
		}
	}
}

void drawOrders()
{
	if (entityManager->blobList.getSize() == 1)
	{
		return;
	}
	
	//graphics->blit(textureManager->getTexture("OrdersFollow"), graphics->screen->w - 126, 60, true);
	//graphics->blit(textureManager->getTexture("OrdersWait"), graphics->screen->w - 74, 60, true);
	//graphics->blit(textureManager->getTexture("OrdersUse"), graphics->screen->w - 100, 34, true);
	//graphics->blit(textureManager->getTexture("OrdersRetreat"), graphics->screen->w - 100, 86, true);
	
	graphics->drawRect(graphics->screen->w - 126, 60, 25, 25, (game->currentOrders != ORDERS_FOLLOW) ? GLColor::lightGrey : GLColor::red, true);
	graphics->drawRect(graphics->screen->w - 74, 60, 25, 25, (game->currentOrders != ORDERS_RETREAT) ? GLColor::lightGrey : GLColor::yellow, true);
	graphics->drawRect(graphics->screen->w - 100, 34, 25, 25, (game->currentOrders != ORDERS_WAIT) ? GLColor::lightGrey : GLColor::green, true);
	graphics->drawRect(graphics->screen->w - 100, 86, 25, 25, (game->currentOrders != ORDERS_USE) ? GLColor::lightGrey : GLColor::skyBlue, true);
}

void drawInfoPanel()
{
	//graphics->drawString(graphics->screen->w / 2, 10, TXT_CENTERED, GLColor::white, true, "Content Type: %d (%d)", player->contentType, player->liquidLevel);
	//graphics->drawString(graphics->screen->w / 2, 30, TXT_CENTERED, GLColor::white, true, "%f %f %f", player->position.x, player->position.y, player->position.z);
	//graphics->drawString(graphics->screen->w / 2, 50, TXT_CENTERED, GLColor::white, true, "%f %f %f", player->velocity.x, player->velocity.y, player->velocity.z);
	
	graphics->setFont(FONT_NORMAL);
	
	drawBlobHealthShieldInfo();
	
	drawWeaponsAndItems();
	
	drawMessages();
	
	drawOrders();
}

==> blobAndConquer-0.2-1.tar.gz: BlobAndConquer/src/controlPanel.cpp <==
/*
Copyright (C) 2006 Parallel Realities

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.

See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

*/

#include "controlPanel.h"

void drawSlotItem(EntityDef *def, int x, int y, float scale)
{
	graphics->setMode(MODE_3D);
	
	if (def->model == NULL)
	{
		return;
	}
	
	static Vector near, far, ray;
	
	graphics->convertToWorldCoords(x, y, &near, &far, &ray);
	
	float adjust = (-2 - near.z) / ray.z;
	
	near.x += (ray.x * adjust);
	near.y += (ray.y * adjust);
	near.z += -2;
	
	scale /= graphics->screen->w;
	
	glEnable(GL_DEPTH_TEST);
	glDepthMask(GL_TRUE);
	
	glPushMatrix();
	{
		glEnable(GL_TEXTURE_2D);
		glDisable(GL_BLEND);
		
		glBindTexture(GL_TEXTURE_2D, def->texture->data);
		
		glTranslatef(near.x, near.y, near.z);
		glRotatef(graphics->getAnimTimer() * 0.5, 1.0, 1.0, 0.0);
		
		glScalef(scale, scale, scale);
		
		glCallList(def->model->data);
	}
	glPopMatrix();
}

void drawBlobHealthShieldInfo()
{
	static float healthPercent;
	static float healthBar, shieldBar, oxygenBar;
	static int fade;
	static int y;
	static String s;
	static GLColor c;
	static Texture *t;
	
	static GLColor darkRed = GLColor::red.darker();
	static GLColor darkYellow = GLColor::yellow.darker();
	static GLColor darkCyan = GLColor::cyan.darker();
	static GLColor darkGreen = GLColor::green.darker();
	
	y = 20;
	
	bool flashBar = ((((int)graphics->getAnimTimer()) % 100) < 50);
	
	for (Unit *unit = (Unit*)entityManager->blobList.getFirstElement() ; unit != NULL ; unit = (Unit*)unit->next)
	{
		if ((unit->health <= -100) || (unit->definition->type == BLOB_MIA))
		{
			continue;
		}
		
		fade = 35;
		
		if (unit->maxShield > 0)
		{
			fade = 40;
		}
		
		if (unit->oxygen < MAX_OXYGEN_IND)
		{
			fade = 45;
		}
		
		graphics->fade(0.5, 30, y - 5, 210, fade);
		
		s.setText("str_%s", unit->getName());
		
		if ((t = textureManager->getTexture(s.getText())) == NULL)
		{
			t = graphics->getGLString(unit->getName());
			textureManager->addTexture(s.getText(), t);
		}
		
		glColor3f(1.0, 1.0, 1.0);
		graphics->blit(t, 35, y, false);
		
		healthPercent = (unit->health / unit->maxHealth) * 100;
		
		healthBar = 200;
		shieldBar = 200;
		oxygenBar = 200;
		
		healthBar /= unit->maxHealth;
		shieldBar /= unit->maxShield;
		oxygenBar /= MAX_OXYGEN;
		
		healthBar *= unit->health;
		shieldBar *= unit->shield;
		oxygenBar *= unit->oxygen;
		
		y += 16;
		
		if (healthPercent >= 75)
		{
			c = darkGreen;
		}
		else if (healthPercent >= 25)
		{
			c = darkYellow;
		}
		else
		{
			c = darkRed;
		}
		
		graphics->drawRect(35, y, 200, 8, c, true);
		
		if (unit == player)
		{
			glColor4f(1.0, 1.0, 1.0, (!game->autoLockTarget) ? 1.0 : 0.15);
			graphics->blit(textureManager->getTexture("NoTarget"), 135, y - 18, false);
		}
		
		if ((unit->health > 0) && (healthPercent < 25))
		{
			if (flashBar)
			{
				graphics->drawRect(35, y, (int)healthBar, 8, c, true);
			}
			
			glColor4f(1.0, 1.0, 1.0, (flashBar) ? 1.0 : 0.5);
			graphics->blit(textureManager->getTexture("Danger"), 185, y - 18, false);
		}
		else if (unit->health > 0)
		{
			graphics->drawRect(35, y, (int)healthBar, 8, c, true);
		}
		
		y += 10;
		
		if (unit->maxShield > 0)
		{
			graphics->drawRect(35, y, 200, 4, darkCyan, true);
			
			if (unit->shield > 0)
			{
				graphics->drawRect(35, y, (int)shieldBar, 4, GLColor::cyan, true);
			}
		}
		
		y += 6;
		
		if (unit->oxygen < MAX_OXYGEN)
		{
			graphics->drawRect(35, y, 200, 4, darkYellow, true);
			
			if (unit->oxygen > 0)
			{
				graphics->drawRect(35, y, (int)oxygenBar, 4, GLColor::yellow, true);
			}
		}
		else if (unit->oxygen != MAX_OXYGEN_IND)
		{
			graphics->drawRect(35, y, 200, 4, GLColor::yellow, true);
		}
		
		if ((unit->definition->type == BLOB_TEEKA) && (game->teekaAvailableTimer > 0))
		{
			graphics->fade(0.75, 30, y - 37, 210, fade);
		}
		
		y += 20;
	}
}

void drawWeaponsAndItems()
{
	int x1 = 5;
	int x2 = (graphics->screen->w - 100) - 5;
	int y1 = graphics->screen->h - 100;
	
	graphics->fade(0.75, x1, y1, 100, 95);
	graphics->outlineRect(x1, y1, 100, 95, GLColor::grey);
	
	graphics->fade(0.75, x2, y1, 100, 95);
	graphics->outlineRect(x2, y1, 100, 95, GLColor::grey);
	
	drawSlotItem(game->selectedWeapon->definition, x1 + 40, graphics->screen->h - 40, 15);
	
	graphics->setMode(MODE_2D);
	
	String s;
	Texture *t;
	
	WeaponDef *weaponDef;
	ItemDef *itemDef;
	
	weaponDef = (WeaponDef*)game->selectedWeapon->definition;
	
	if (!weaponDef->unlimited)
	{
		if ((t = textureManager->getTexture("str_current_ammo")) == NULL)
		{
			t = graphics->getGLString("%d", game->selectedWeapon->currentAmmo);
			textureManager->addTexture("str_current_ammo", t);
		}
		
		glColor3f(1.0, 1.0, 1.0);
		graphics->blit(t, 55, graphics->screen->h - 18, true);
	}
	
	for (int i = 0 ; i < 4 ; i++)
	{
		if (game->weapon[i] != NULL)
		{
			weaponDef = (WeaponDef*)game->weapon[i]->definition;
			
			s.setText("str_weapon_%d", i);
			
			if ((t = textureManager->getTexture(s.getText())) == NULL)
			{
				if (weaponDef->unlimited)
				{
					t = graphics->getGLString(game->weapon[i]->definition->getName());
				}
				else
				{
					t = graphics->getGLString("%s: %d", game->weapon[i]->definition->getName(), game->weapon[i]->currentAmmo);
				}
				
				textureManager->addTexture(s.getText(), t);
			}
			
			glColor3f(1.0, 1.0, 1.0);
			
			if (game->weapon[i]->currentAmmo == 0)
			{
				glColor3f(0.5, 0.5, 0.5);
			}
			
			if (game->weapon[i] == game->selectedWeapon)
			{
				glColor3f(0.0, 1.0, 0.0);
			}
		
			graphics->blit(t, 110, y1, false);
		}
		
		y1 += 25;
	}
	
	y1 = graphics->screen->h - 100;
	x2 -= 5;
	
	for (int i =  0 ; i < 5 ; i++)
	{
		if (game->item[i] != NULL)
		{
			itemDef = (ItemDef*)game->item[i]->definition;
			
			s.setText("str_item_%d", i);
			
			if ((t = textureManager->getTexture(s.getText())) == NULL)
			{
				if (itemDef->type == ITM_KEYCARD)
				{
					t = graphics->getGLString("%s (%s)", itemDef->getName(), game->item[i]->getName());
				}
				else if (itemDef->collatable)
				{
					t = graphics->getGLString("%s (%d)", itemDef->getName(), game->item[i]->itemPower);
				}
				else
				{
					char *translatedName = (itemDef->type < ITM_CUSTOM_FIRST) ?  itemDef->getName() : localeManager->translate(itemDef->getName());
					
					t = graphics->getGLString("%s", translatedName);
				}
				
				textureManager->addTexture(s.getText(), t);
			}
			
			glColor3f(1.0, 1.0, 1.0);
			
			graphics->blit(t, x2 - t->iw, y1, false);
		}
		
		y1 += 20;
	}
}

void drawMessages()
{
	Texture *t;
	String s;
	
	int y1 = graphics->screen->h - 100;
	
	for (int i = 0 ; i < 4 ; i++)
	{
		if (game->infoMessage[i].life > 0)
		{
			switch (game->infoMessage[i].type)
			{
				case INFO_PICKUP:
					glColor4fv(GLColor::cyan.color);
					break;
					
				case INFO_BAD:
					glColor4fv(GLColor::red.color);
					break;
					
				case INFO_GOOD:
					glColor4fv(GLColor::green.color);
					break;
					
				case INFO_HINT:
					glColor4fv(GLColor::yellow.color);
					break;
					
				case INFO_GENERAL:
					glColor4fv(GLColor::white.color);
					break;
			}
			
			s.setText("str_message_%d", i);
			
			if (game->infoMessage[i].redraw)
			{
				textureManager->removeTexture(s.getText());
				game->infoMessage[i].redraw = false;
			}
			
			if ((t = textureManager->getTexture(s.getText())) == NULL)
			{
				t = graphics->getGLString(game->infoMessage[i].message.getText());
				textureManager->addTexture(s.getText(), t);
			}
		
			graphics->blit(t, graphics->screen->w / 2, y1, true);
			
			y1 += 25;
			
			game->infoMessage[i].life -= engine->getTimeDifference(TD_LOGIC);
			
			if (game->infoMessage[i].life <= 0)
			{
				textureManager->removeTexture(s.getText());
			}
		}
	}
		
	if (game->gameplayMessage.life > 0)
	{
		s.setText("str_message_gameplay");
			
		if ((t = textureManager->getTexture(s.getText())) == NULL)
		{
			t = graphics->getGLString(game->gameplayMessage.message.getText());
			textureManager->addTexture(s.getText(), t);
		}
		
		int x = (graphics->screen->w - t->iw) / 2;
		int y = graphics->screen->h - 135;
		int w = t->iw;
		int h = t->ih;
		
		graphics->fade(0.65, x - 10, y - 5, w + 15, h + 10);
		graphics->outlineRect(x - 10, y - 5, w + 15, h + 10, GLColor::lightGrey);
		glColor3f(1.0, 1.0, 1.0);
		glEnable(GL_BLEND);
		graphics->blit(t, x, y, false);
		
		game->gameplayMessage.life -= engine->getTimeDifference(TD_LOGIC);
			
		if (game->gameplayMessage.life <= 0)
		{
			textureManager->removeTexture(s.getText());
		}
	}
}

void drawOrders()
{
	if (entityManager->blobList.getSize() == 1)
	{
		return;
	}
	
	//graphics->blit(textureManager->getTexture("OrdersFollow"), graphics->screen->w - 126, 60, true);
	//graphics->blit(textureManager->getTexture("OrdersWait"), graphics->screen->w - 74, 60, true);
	//graphics->blit(textureManager->getTexture("OrdersUse"), graphics->screen->w - 100, 34, true);
	//graphics->blit(textureManager->getTexture("OrdersRetreat"), graphics->screen->w - 100, 86, true);
	
	graphics->drawRect(graphics->screen->w - 126, 60, 25, 25, (game->currentOrders != ORDERS_FOLLOW) ? GLColor::lightGrey : GLColor::red, true);
	graphics->drawRect(graphics->screen->w - 74, 60, 25, 25, (game->currentOrders != ORDERS_RETREAT) ? GLColor::lightGrey : GLColor::yellow, true);
	graphics->drawRect(graphics->screen->w - 100, 34, 25, 25, (game->currentOrders != ORDERS_WAIT) ? GLColor::lightGrey : GLColor::green, true);
	graphics->drawRect(graphics->screen->w - 100, 86, 25, 25, (game->currentOrders != ORDERS_USE) ? GLColor::lightGrey : GLColor::skyBlue, true);
}

void drawInfoPanel()
{
	//graphics->drawString(graphics->screen->w / 2, 10, TXT_CENTERED, GLColor::white, true, "Drawing: %d", entityManager->drawList.getSize());
	//graphics->drawString(graphics->screen->w / 2, 30, TXT_CENTERED, GLColor::white, true, "%f %f %f", player->position.x, player->position.y, player->position.z);
	//graphics->drawString(graphics->screen->w / 2, 50, TXT_CENTERED, GLColor::white, true, "%f %f %f", player->velocity.x, player->velocity.y, player->velocity.z);
	//graphics->drawString(graphics->screen->w / 2, 70, TXT_CENTERED, GLColor::white, true, "On Ground %d", (player->flags & EF_ONGROUND));
	//graphics->drawString(graphics->screen->w / 2, 90, TXT_CENTERED, GLColor::white, true, "Content %ld", player->contentType);
	
	graphics->setFont(FONT_NORMAL);
	
	drawBlobHealthShieldInfo();
	
	drawWeaponsAndItems();
	
	drawMessages();
	
	drawOrders();
}
